@@ -181,7 +181,7 @@ impl InfiniteAreaLight {
         if texmap != "" {
             let file = std::fs::File::open(texmap).unwrap();
             let reader = BufReader::new(file);
-            let img_result = image::hdr::HdrDecoder::with_strictness(reader, false);
+            let img_result = image::codecs::hdr::HdrDecoder::with_strictness(reader, false);
             if img_result.is_ok() {
                 if let Ok(hdr) = img_result {
                     let meta = hdr.metadata();
